==> familia_0.1.tar.gz: familia/src/drawingarea.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _DRAWINGAREA_H
#define _DRAWINGAREA_H

#include <gtkmm.h>
#include <vector>

#include "file/file.h"
#include "file/individual.h"

class DrawingArea : public Gtk::DrawingArea {
public:
  typedef file::Individual _Individual;
  typedef std::map<int, _Individual> _Individuals;

  DrawingArea();
  virtual ~DrawingArea();
protected:  
  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);

  struct {
    Glib::RefPtr<Gdk::Pixbuf> male;
    Glib::RefPtr<Gdk::Pixbuf> female;
  } images;
};

#endif //

==> familia_0.1.2.tar.gz: familia/src/drawingarea.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _DRAWINGAREA_H
#define _DRAWINGAREA_H

#include <gtkmm.h>
#include <vector>

#include "file/file.h"
#include "file/individual.h"

class DrawingArea : public Gtk::DrawingArea {
public:
  typedef file::Individual _Individual;
  typedef std::vector<_Individual> _Individuals;
  int index;

  DrawingArea();
  virtual ~DrawingArea();
protected:  
  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);

  struct {
    Glib::RefPtr<Gdk::Pixbuf> male;
    Glib::RefPtr<Gdk::Pixbuf> female;
  } images;
};

#endif //
